Flask-Images
============

[![Build Status](https://travis-ci.org/mikeboers/Flask-Images.png?branch=master)](https://travis-ci.org/mikeboers/Flask-Images)

Flask-Images is a Flask extension that provides dynamic image resizing for your application.

[Read the docs][docs], [try the demo][demo], have fun, and good luck!

[docs]: https://mikeboers.github.io/Flask-Images/
[demo]: https://flask-images.herokuapp.com/
